@@ -231,6 +231,30 @@ class TestFormViews(TestCase, MoloTestCaseMixin):
         self.assertContains(response, molo_form_field.label)
         self.assertContains(response, 'python</span> 1')
 
+    def test_show_results_option_ajax(self):
+        molo_form_page, molo_form_field = \
+            self.create_molo_form_page_with_field(
+                parent=self.section_index,
+                allow_anonymous_submissions=True,
+                show_results=True,
+            )
+
+        response = self.client.get(molo_form_page.url)
+        self.assertContains(response, molo_form_page.title)
+        self.assertContains(response, molo_form_page.introduction)
+        self.assertContains(response, molo_form_field.label)
+
+        response = self.client.post(molo_form_page.url, {
+            "ajax": 'True',
+            "article_page": self.article.pk,
+            molo_form_field.label.lower().replace(' ', '-'): 'python'
+        }, follow=True)
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(
+            response.content,
+            b'{"Your favourite animal": {"python": 1}}'
+        )
+
     def test_show_results_as_percentage_option(self):
         molo_form_page, molo_form_field = \
             self.create_molo_form_page_with_field(
@@ -817,6 +841,57 @@ class TestFormViews(TestCase, MoloTestCaseMixin):
             'article_page', str(results.content)
         )
 
+    def test_article_form_result_calculations_ajax(self):
+        """
+        with an article page
+        """
+        form = create_molo_form_page(
+            self.forms_index,
+            title='test form',
+            display_form_directly=True,
+            show_results=True,
+            save_article_object=True,
+            allow_anonymous_submissions=True,
+        )
+        article = self.mk_article(self.section, title='article 2')
+        field = MoloFormField.objects.create(
+            page=form, label='a, b or c?', field_type='singleline')
+
+        ArticlePageForms.objects.create(page=article, form=form)
+        ArticlePageForms.objects.create(page=self.article, form=form)
+
+        form_data = {field.clean_name: 'a', 'article_page': article.pk}
+        MoloFormSubmission.objects.create(
+            page=form, article_page=article, form_data=json.dumps(form_data))
+
+        form_data.update({'article_page': self.article.pk})
+
+        success_url = reverse('molo.forms:success_article_form', kwargs={
+            'slug': form.slug, 'article': self.article.pk})
+
+        results = self.client.post(form.get_full_url(), data=form_data)
+        self.assertEqual(results.status_code, 302)
+        self.assertEqual(results.url, success_url)
+
+        results = self.client.get(success_url + '?format=json')
+        self.assertEqual(results.status_code, 200)
+        self.assertEqual(
+            b'{"a, b or c?": {"a": 1}, "article_page": {"%d": 1}}'
+            % self.article.pk,
+            results.content
+        )
+
+        form.show_results_as_percentage = True
+        form.save()
+
+        results = self.client.get(success_url + '?format=json')
+        self.assertEqual(results.status_code, 200)
+        self.assertEqual(
+            b'{"a, b or c?": {"a": 100}, "article_page": {"%d": 100}}'
+            % self.article.pk,
+            results.content
+        )
+
 
 class TestDeleteButtonRemoved(TestCase, MoloTestCaseMixin):
 
@@ -1495,6 +1570,20 @@ class TestAPIEndpointsView(TestCase, MoloTestCaseMixin):
         form.save_revision().publish()
         return form
 
+    def test_article_page_api_returns_linked_forms(self):
+        section = self.mk_section(self.section_index, title='section')
+        article = self.mk_article(section, title='article')
+        form = self.new_form("Article Form")
+        article_page_form = ArticlePageForms(form=form, page=article)
+        article.forms.add(article_page_form)
+        article.save_revision().publish()
+        response = self.client.get('/api/v2/pages/%s/' % article.id)
+
+        obj = response.json()
+        self.assertIn("forms", obj)
+        self.assertEqual(len(obj['forms']), 1)
+        self.assertEqual(obj['forms'][0]['form']['id'], form.id)
+
     def test_api_list_endpoint_shows_forms(self):
         response = self.client.get('/api/v2/forms/')
 
